/**
* anoFile - Lightweight jQuery Ajax File Upload
* 
* @copyright Anowave
* @author Angel Kostadinov
* @version 1.0
*/
var anoFile = (function()
{
	return {
		form: 		null,
		iframe: 	[],
		containers: [],
		format:		null,
		listeners: 
		{
			before: function(event, ui){},
			success: function(event, ui){}
		},
		on: function(listeners)
		{
			this.listeners = $.extend(this.listeners, listeners);
			
			return this;
		},
		accept: function(format)
		{
			this.format = format;
			
			return this;
		},
		options:
		{
			id: "myAjaxUpload"
		},
		complete:function(event, response) /* Upload complete */
		{
			this.getForm(event.target.id).removeAttr('target');
			
			var json = $.parseJSON(response.text());
				
			this.listeners.success.apply(this, [event, 
			{
				input: this.getForm(event.target.id).find(':file').parent(),
				json:  json
			}]);
		},
		reset: function()
		{
			if (this.form)
			{
				this.form = null;
			}
			
			if (this.iframe)
			{
				this.iframe.remove();
				
				this.iframe = null;
			}
			
			return this;
		},
		loaded: function(event)
		{
			var iframe = $(event.target);
			
			if (iframe.contents().attr("location") == "about:blank")
			{
				return;
			}
			
			/* Loaded callback */
			iframe.trigger("complete",[iframe.contents()]);
			
			return false;
		},
		upload: function(event)
		{	
			/* Call before listener  */
			this.listeners.before.apply(this, [
			{
				input: event.target
			}]);
			
			return this.getForm(event.target.id).attr("target", event.target.id).trigger("submit");
		},
		submit: function()
		{
			return true;
		},
		getFileInput: function(id)
		{
			return $('<input/>',
			{
				id: 		id,
				name: 		"upload[]",
				type: 		"file",
				multiple: 	"multiple",
				accept: 	this.format
			}).bind(
			{
				change: this.delegate(this, this.upload)
			});
		},
		getForm: function(id)
		{
			return $(':file[id=' + id + ']').parents('form:first');
		},
		render: function(containers)
		{
			var index = 0;
			
			this.containers = $(containers);
			
			this.containers.each(this.delegate(this, function(index, item)
			{
				var id = 'myAjaxUpload' + (++index), iframe = $('<iframe />',
				{
					id: 	id,
					name:	id,
					scr: 	"about:blank"
				}).hide().load(this.delegate(this,this.loaded)).bind("complete",this.delegate(this,this.complete)).appendTo(document.body);
		
				if (-1 != navigator.userAgent.toLowerCase().indexOf('msie 7.0'))
				{
					document.frames[id].name = id;
				}
			
				this.getFileInput(id).appendTo(item);
			}))
		},
		delegate: function(target, method, args)
		{
			return (typeof method === "function") ? function() 
			{ 
				/* Override prototype */
				arguments.push = Array.prototype.push;
				
				/* Push additional arguments */
				for (var arg in args)
				{
					arguments.push(args[arg]);
				}
				return method.apply(target, arguments); 
			} : function()
			{
				return false;
			};
		}
	}
})();